@@ -23,6 +23,7 @@ You should have received a copy of the GNU General Public License
 along with Sentry-Trello.  If not, see <http://www.gnu.org/licenses/>.
 '''
 from django import forms
+from django.utils.translation import ugettext_lazy as _
 
 from sentry.conf import settings
 from sentry.plugins import Plugin
@@ -31,24 +32,24 @@ from trello import TrelloApi
 import sentry_trello
 
 class TrelloSettingsForm(forms.Form):
-    key = forms.CharField(help_text='Trello API Key')
-    token = forms.CharField(help_text='Trello API Token')
-    board_list = forms.CharField(help_text='ID of the list to add a card to')
+    key = forms.CharField(help_text=_('Trello API Key'))
+    token = forms.CharField(help_text=_('Trello API Token'))
+    board_list = forms.CharField(help_text=_('ID of the list to add a card to'))
 
 class TrelloCard(Plugin):
     author = 'Damian Zaremba'
     author_url = 'http://damianzaremba.co.uk'
-    title = 'Trello'
+    title = _('Trello')
     description = 'Create Trello cards on exceptions.'
 
     resource_links = [
-        ('How do I configure this?',
-			'https://github.com/damianzaremba/sentry-trello/blob/master/HOW_TO_SETUP.md'),
-        ('Bug Tracker', 'https://github.com/damianzaremba/sentry-trello/issues'),
-        ('Source', 'https://github.com/damianzaremba/sentry-trello'),
+        (_('How do I configure this?'),
+            'https://github.com/damianzaremba/sentry-trello/blob/master/HOW_TO_SETUP.md'),
+        (_('Bug Tracker'), 'https://github.com/damianzaremba/sentry-trello/issues'),
+        (_('Source'), 'https://github.com/damianzaremba/sentry-trello'),
     ]
 
-    conf_title = 'Trello'
+    conf_title = _('Trello')
     conf_key = 'trello'
 
     version = sentry_trello.VERSION
@@ -74,13 +75,17 @@ class TrelloCard(Plugin):
         link = '%s/%s/group/%d/' % (settings.URL_PREFIX, group.project.slug,
                                     group.id)
 
-        message = 'Server: %s\n' % event.server_name
-        message += 'Group: %s\n' % event.group
-        message += 'Logger: %s\n' % event.logger
-        message += 'Message: %s\n' % event.message
-        message += '\n%s\n' % link
+        message = 'Server: %s\n\n' % event.server_name
+        message += 'Group: %s\n\n' % event.group
+        message += 'Logger: %s\n\n' % event.logger
+        message += 'Message:\n%s\n\n' % event.message
+        message += '%s\n' % link
 
-        self.make_card(title, message, event)
+        try:
+            self.make_card(title, message, event)
+        except Exception, e:
+            raise forms.ValidationError(
+                    _("Unable to make trello card: %s") % e)
 
     def make_card(self, title, message, event):
 
